@@ -49,14 +49,11 @@
 
 #include <gtk/gtk.h>
 
-#include <dbus/dbus-glib.h>
-#include <dbus/dbus-glib-lowlevel.h>
-
 #include "gdm-settings-client.h"
 #include "gdm-settings-keys.h"
 #include "gdm-profile.h"
 
-#include "gdm-greeter-client.h"
+#include "gdm-client.h"
 #include "gdm-greeter-login-window.h"
 #include "gdm-user-chooser-widget.h"
 #include "gdm-session-option-widget.h"
@@ -1433,9 +1430,7 @@ on_users_loaded (GdmUserChooserWidget  *user_chooser,
 
         update_banner_message (login_window);
 
-        if (!login_window->priv->user_list_disabled) {
-                gtk_widget_show (login_window->priv->user_chooser);
-        }
+        gtk_widget_show (login_window->priv->user_chooser);
 
         enable_waiting_extensions (login_window);
 
@@ -1444,6 +1439,8 @@ on_users_loaded (GdmUserChooserWidget  *user_chooser,
                 request_timed_login (login_window);
         } else if (can_jump_to_authenticate (login_window)) {
 
+                gtk_widget_hide (login_window->priv->user_chooser);
+
                 /* jump straight to authenticate */
                 g_debug ("GdmGreeterLoginWindow: jumping straight to authenticate");
                 g_signal_emit (G_OBJECT (login_window), signals[USER_SELECTED],
